@@ -10,6 +10,9 @@ set -o pipefail
 #ensure parallel builds
 export MAKEFLAGS=-j8
 
+#needed to find homebrew's libffi on osx
+export PKG_CONFIG_PATH=/usr/local/opt/libffi/lib/pkgconfig
+
 ##### START FUNCTIONS #####
 
 #function HELP
@@ -86,7 +89,7 @@ CHECK_WARNINGS() {
 # print warnings found in the compile-stage output
 # $1 = file with the compile-stage output
 COMPILE_WARNINGS() {
-  whitelist='\(Value[[:space:]]descriptions\|g-ir-scanner:\|clang.*argument[[:space:]]unused[[:space:]]during[[:space:]]compilation\)'
+  whitelist='\(Value[[:space:]]descriptions\|unused[[:space:]]declarations\|g-ir-scanner:\|clang.*argument[[:space:]]unused[[:space:]]during[[:space:]]compilation\|U_PLATFORM_HAS_WINUWP_API\|DB_DBM_HSEARCH\|const[[:space:]]DBT\|db\.h\)'
   CHECK_WARNINGS $1 "warning:" "$whitelist"
 }
 
@@ -94,14 +97,14 @@ COMPILE_WARNINGS() {
 # print warnings found in the cppcheck output
 # $1 = file with the cppcheck output
 CPPCHECK_WARNINGS() {
-  CHECK_WARNINGS $1 "\(warning\)" ""
+  CHECK_WARNINGS $1 "\(warning\|error\|information\|portability\)" ""
 }
 
 #function TIDY_WARNINGS:
 # print warnings find in the clang-tidy output
 # $1 = file with the clang-tidy output
 TIDY_WARNINGS() {
-  whitelist='\(Value[[:space:]]descriptions\|g-ir-scanner:\|clang.*argument[[:space:]]unused[[:space:]]during[[:space:]]compilation\|modernize-\|cppcoreguidelines-pro-type-const-cast\|cppcoreguidelines-pro-type-reinterpret-cast\|cppcoreguidelines-pro-type-vararg\|cppcoreguidelines-pro-bounds-pointer-arithmetic\|google-build-using-namespace\|llvm-include-order\|hicpp-use-equals-default\|cppcoreguidelines-no-malloc)'
+  whitelist='\(Value[[:space:]]descriptions\|unused[[:space:]]declarations\|g-ir-scanner:\|clang.*argument[[:space:]]unused[[:space:]]during[[:space:]]compilation\|modernize-\|cppcoreguidelines-pro-type-const-cast\|cppcoreguidelines-pro-type-reinterpret-cast\|cppcoreguidelines-pro-type-vararg\|cppcoreguidelines-pro-bounds-pointer-arithmetic\|google-build-using-namespace\|llvm-include-order\|hicpp-use-equals-default\|cppcoreguidelines-no-malloc)'
   CHECK_WARNINGS $1 "warning:" "$whitelist"
 }
 
@@ -109,7 +112,7 @@ TIDY_WARNINGS() {
 # print warnings found in the scan-build output
 # $1 = file with the scan-build output
 SCAN_WARNINGS() {
-  whitelist='\(Value[[:space:]]descriptions\|icalerror.*Dereference[[:space:]]of[[:space:]]null[[:space:]]pointer\)'
+  whitelist='\(Value[[:space:]]descriptions\|unused[[:space:]]declarations\|icalerror.*Dereference[[:space:]]of[[:space:]]null[[:space:]]pointer\)'
   CHECK_WARNINGS $1 "warning:" "$whitelist"
 }
 
@@ -139,9 +142,9 @@ CLEAN() {
 BUILD() {
   cd $TOP
   CONFIGURE "$1" "$2"
-  make |& tee make.out || exit 1
+  make 2>&1 | tee make.out || exit 1
   COMPILE_WARNINGS make.out
-  make test |& tee make-test.out || exit 1
+  make test 2>&1 | tee make-test.out || exit 1
   CLEAN
 }
 
@@ -151,7 +154,7 @@ BUILD() {
 # $2 = CMake options
 GCC_BUILD() {
   name="$1-gcc"
-  if ( test $rungccbuild -eq 0 )
+  if ( test $rungccbuild -ne 1 )
   then
     echo "===== GCC BUILD TEST $1 DISABLED DUE TO COMMAND LINE OPTION ====="
     return
@@ -169,7 +172,7 @@ GCC_BUILD() {
 # $2 = CMake options
 CLANG_BUILD() {
   name="$1-clang"
-  if ( test $runclangbuild -eq 0 )
+  if ( test $runclangbuild -ne 1 )
   then
     echo "===== CLANG BUILD TEST $1 DISABLED DUE TO COMMAND LINE OPTION ====="
     return
@@ -187,7 +190,7 @@ CLANG_BUILD() {
 # $2 = CMake options
 ASAN_BUILD() {
   name="$1-asan"
-  if ( test $runasanbuild -eq 0 )
+  if ( test $runasanbuild -ne 1 )
   then
     echo "===== ASAN BUILD TEST $1 DISABLED DUE TO COMMAND LINE OPTION ====="
     return
@@ -204,7 +207,7 @@ ASAN_BUILD() {
 # $2 = CMake options
 TSAN_BUILD() {
   name="$1-tsan"
-  if ( test $runtsanbuild -eq 0 )
+  if ( test $runtsanbuild -ne 1 )
   then
     echo "===== TSAN BUILD TEST $1 DISABLED DUE TO COMMAND LINE OPTION ====="
     return
@@ -221,7 +224,7 @@ TSAN_BUILD() {
 # $2 = CMake options
 CPPCHECK() {
   name="$1-cppcheck"
-  if ( test $runcppcheck -eq 0 )
+  if ( test $runcppcheck -ne 1 )
   then
     echo "===== CPPCHECK TEST $1 DISABLED DUE TO COMMAND LINE OPTION ====="
     return
@@ -233,7 +236,7 @@ CPPCHECK() {
   cd $TOP
   SET_GCC
   CONFIGURE "$name" "$2"
-  make |& tee make.out || exit 1
+  make 2>&1 | tee make.out || exit 1
 
   echo "===== START CPPCHECK: $1 ======"
   cd $TOP
@@ -246,6 +249,11 @@ CPPCHECK() {
            -D size_t="unsigned long" \
            -D bswap32="" \
            -D PTHREAD_RECURSIVE_MUTEX_INITIALIZER_NP="" \
+           -D _unused="(void)" \
+           -D F_OK=0 \
+           -D R_OK=0 \
+           -U YYSTYPE \
+           -U PVL_USE_MACROS \
            -I $BDIR \
            -I $BDIR/src/libical \
            -I $BDIR/src/libicalss \
@@ -257,7 +265,8 @@ CPPCHECK() {
       grep -v 'cannot find all the include files' | \
       grep -v Net-ICal | \
       grep -v icalssyacc\.c  | \
-      grep -v icalsslexer\.c | tee cppcheck.out
+      grep -v icalsslexer\.c | \
+      grep -v _cxx\. | tee cppcheck.out
   CPPCHECK_WARNINGS cppcheck.out
   rm -f cppcheck.out
   CLEAN
@@ -270,9 +279,9 @@ CPPCHECK() {
 # $2 = CMake options
 SPLINT() {
   name="$1-splint"
-  if ( test $runsplint -eq 0 )
+  if ( test $runsplint -ne 1 )
   then
-    echo "===== SPLIT TEST $1 DISABLED DUE TO COMMAND LINE OPTION ====="
+    echo "===== SPLINT TEST $1 DISABLED DUE TO COMMAND LINE OPTION ====="
     return
   fi
   COMMAND_EXISTS "splint"
@@ -282,7 +291,7 @@ SPLINT() {
   cd $TOP
   SET_GCC
   CONFIGURE "$name" "$2"
-  make |& tee make.out || exit 1
+  make 2>&1 | tee make.out || exit 1
 
   echo "===== START SPLINT: $1 ======"
   cd $TOP
@@ -335,7 +344,9 @@ SPLINT() {
        -I $TOP/src/libicalss \
        -I $TOP/src/libicalvcal \
        -I $TOP/src/libical-glib | \
-  cat - |& tee splint-$name.out
+  grep -v '[[:space:]]Location[[:space:]]unknown[[:space:]]' | \
+  grep -v '[[:space:]]Code[[:space:]]cannot[[:space:]]be[[:space:]]parsed.' | \
+  cat - 2>&1 | tee splint-$name.out
   status=${PIPESTATUS[0]}
   if ( test $status -gt 0 )
   then
@@ -352,7 +363,7 @@ SPLINT() {
 # $1 = the name of the test (which will have "-tidy" appended)
 # $2 = CMake options
 CLANGTIDY() {
-  if ( test $runtidy -eq 0 )
+  if ( test $runtidy -ne 1 )
   then
     echo "===== CLANG-TIDY TEST $1 DISABLED DUE TO COMMAND LINE OPTION ====="
     return
@@ -362,7 +373,7 @@ CLANGTIDY() {
   cd $TOP
   SET_CLANG
   CONFIGURE "$1-tidy" "$2 -DCMAKE_CXX_CLANG_TIDY=clang-tidy;-checks=*"
-  cmake --build . |& tee make-tidy.out || exit 1
+  cmake --build . 2>&1 | tee make-tidy.out || exit 1
   TIDY_WARNINGS make-tidy.out
   CLEAN
   echo "===== END CLANG-TIDY: $1 ====="
@@ -373,7 +384,7 @@ CLANGTIDY() {
 # $1 = the name of the test (which will have "-scan" appended)
 # $2 = CMake options
 CLANGSCAN() {
-  if ( test $runscan -eq 0 )
+  if ( test $runscan -ne 1 )
   then
     echo "===== SCAN-BUILD TEST $1 DISABLED DUE TO COMMAND LINE OPTION ====="
     return
@@ -389,7 +400,7 @@ CLANGSCAN() {
   rm -rf *
   scan-build cmake .. "$2" || exit 1
 
-  scan-build make |& tee make-scan.out || exit 1
+  scan-build make 2>&1 | tee make-scan.out || exit 1
   SCAN_WARNINGS make-scan.out
   CLEAN
   echo "===== END CLANG-SCAN: $1 ====="
@@ -398,7 +409,7 @@ CLANGSCAN() {
 #function KRAZY
 # runs a krazy2 test
 KRAZY() {
-  if ( test $runkrazy -eq 0 )
+  if ( test $runkrazy -ne 1 )
   then
     echo "===== KRAZY TEST DISABLED DUE TO COMMAND LINE OPTION ====="
     return
@@ -406,7 +417,7 @@ KRAZY() {
   COMMAND_EXISTS "krazy2all"
   echo "===== START KRAZY ====="
   cd $TOP
-  krazy2all |& tee krazy.out
+  krazy2all 2>&1 | tee krazy.out
   status=$?
   if ( test $status -gt 0 )
   then
@@ -419,7 +430,8 @@ KRAZY() {
 
 ##### END FUNCTIONS #####
 
-TEMP=`getopt -o hkctbslgad --long help,no-krazy,no-cppcheck,no-tidy,no-scan,no-splint,no-clang-build,no-gcc-build,no-asan-build,no-tsan-build -- "$@"`
+#TEMP=`getopt -o hkctbslgad --long help,no-krazy,no-cppcheck,no-tidy,no-scan,no-splint,no-clang-build,no-gcc-build,no-asan-build,no-tsan-build -- "$@"`
+TEMP=`getopt hkctbslgad $*`
 if [ $? != 0 ] ; then echo "Terminating..." >&2 ; exit 1 ; fi
 # Note the quotes around `$TEMP': they are essential!
 eval set -- "$TEMP"
@@ -444,7 +456,7 @@ while true ; do
         -l|--no-clang-build) runclangbuild=0; shift;;
         -g|--no-gcc-build)   rungccbuild=0;   shift;;
         -a|--no-asan-build)  runasanbuild=0;  shift;;
-        -d|--no-tsan-build)  runtsanbuild=0;shift;;
+        -d|--no-tsan-build)  runtsanbuild=0;  shift;;
         --) shift; break;;
         *)  echo "Internal error!"; exit 1;;
     esac
@@ -457,8 +469,9 @@ cd ..
 TOP=`pwd`
 BDIR=""
 
-CMAKEOPTS="-DCMAKE_BUILD_TYPE=Debug -DGOBJECT_INTROSPECTION=True -DICAL_GLIB=True"
-TZCMAKEOPTS="-DCMAKE_BUILD_TYPE=Debug -DUSE_BUILTIN_TZDATA=True -DGOBJECT_INTROSPECTION=True -DICAL_GLIB=True"
+CMAKEOPTS="-DCMAKE_BUILD_TYPE=Debug -DGOBJECT_INTROSPECTION=False -DICAL_GLIB=False -DICAL_BUILD_DOCS=False"
+UUCCMAKEOPTS="$CMAKEOPTS -DCMAKE_DISABLE_FIND_PACKAGE_ICU=True"
+TZCMAKEOPTS="$CMAKEOPTS -DUSE_BUILTIN_TZDATA=True"
 
 #Static code checkers
 KRAZY
@@ -474,25 +487,37 @@ CLANGTIDY test2builtin "$TZCMAKEOPTS"
 #GCC based build tests
 GCC_BUILD test1 ""
 GCC_BUILD test2 "$CMAKEOPTS"
-GCC_BUILD test1cross "-DCMAKE_TOOLCHAIN_FILE=$TOP/cmake/Toolchain-Linux-GCC-i686.cmake"
-GCC_BUILD test2cross "-DCMAKE_TOOLCHAIN_FILE=$TOP/cmake/Toolchain-Linux-GCC-i686.cmake $CMAKEOPTS"
+GCC_BUILD test3 "$UUCCMAKEOPTS"
+if (test "`uname -s`" = "Linux")
+then
+    echo "Temporarily disable cross-compile tests"
+#  GCC_BUILD test1cross "-DCMAKE_TOOLCHAIN_FILE=$TOP/cmake/Toolchain-Linux-GCC-i686.cmake"
+#  GCC_BUILD test2cross "-DCMAKE_TOOLCHAIN_FILE=$TOP/cmake/Toolchain-Linux-GCC-i686.cmake $CMAKEOPTS"
+fi
 GCC_BUILD test1builtin "-DUSE_BUILTIN_TZDATA=True"
 GCC_BUILD test2builtin "$TZCMAKEOPTS"
 
 #Clang based build tests
 CLANG_BUILD test1 ""
 CLANG_BUILD test2 "$CMAKEOPTS"
-CLANG_BUILD test1cross "-DCMAKE_TOOLCHAIN_FILE=$TOP/cmake/Toolchain-Linux-GCC-i686.cmake"
-CLANG_BUILD test2cross "-DCMAKE_TOOLCHAIN_FILE=$TOP/cmake/Toolchain-Linux-GCC-i686.cmake $CMAKEOPTS"
+CLANG_BUILD test3 "$UUCCMAKEOPTS"
+if (test "`uname -s`" = "Linux")
+then
+    echo "Temporarily disable cross-compile tests"
+#  CLANG_BUILD test1cross "-DCMAKE_TOOLCHAIN_FILE=$TOP/cmake/Toolchain-Linux-GCC-i686.cmake"
+#  CLANG_BUILD test2cross "-DCMAKE_TOOLCHAIN_FILE=$TOP/cmake/Toolchain-Linux-GCC-i686.cmake $CMAKEOPTS"
+fi
 
 #Address sanitizer
 ASAN_BUILD test1asan ""
 ASAN_BUILD test2asan "$CMAKEOPTS"
 ASAN_BUILD test3asan "$TZCMAKEOPTS"
+ASAN_BUILD test4asan "$UUCCMAKEOPTS"
 
 #Thread sanitizer
 TSAN_BUILD test1tsan ""
 TSAN_BUILD test2tsan "$CMAKEOPTS"
 TSAN_BUILD test3tsan "$TZCMAKEOPTS"
+TSAN_BUILD test4tsan "$UUCCMAKEOPTS"
 
 echo "ALL TESTS COMPLETED SUCCESSFULLY"
