@@ -1096,6 +1096,7 @@ void generate_forward_declarations_header_file(GList *structures)
     gchar *typeName;
     gchar *typeKind;
     GList *link;
+    GList *typeNamesList = NULL;
     GHashTable *typeNames;
     GHashTableIter iter_table;
     gpointer key;
@@ -1141,7 +1142,6 @@ void generate_forward_declarations_header_file(GList *structures)
         if (c == '$') {
             if ((c = fgetc(in)) != '{' && c != '^') {
                 printf("The following char is not {");
-                g_free (buffer);
                 fclose(in);
                 fclose(out);
                 return;
@@ -1156,13 +1156,18 @@ void generate_forward_declarations_header_file(GList *structures)
             if (g_strcmp0(buffer, "forward_declarations") == 0) {
                 g_hash_table_iter_init(&iter_table, typeNames);
                 while (g_hash_table_iter_next(&iter_table, &key, &value)) {
-                    typeName = (gchar *)key;
+                    typeNamesList = g_list_prepend(typeNamesList, g_strdup(key));
+                }
+                typeNamesList = g_list_sort(typeNamesList, (GCompareFunc)g_strcmp0);
+                for (link = g_list_first(typeNamesList); link != NULL; link = g_list_next(link)) {
+                    typeName = link->data;
                     write_str(out, "typedef struct _");
                     write_str(out, typeName);
                     write_str(out, " ");
                     write_str(out, typeName);
                     write_str(out, ";\n");
                 }
+                g_list_free_full(typeNamesList, g_free);
             } else if (g_strcmp0(buffer, "upperSnake") == 0) {
                 write_str(out, "I_CAL_FORWARD_DECLARATIONS");
             } else {
@@ -1440,6 +1445,7 @@ static gboolean is_enum_type(const gchar *type)
         structureKind = g_hash_table_lookup(type2kind, trueType);
         res = g_strcmp0(structureKind, "enum") == 0;
     }
+    g_free (trueType);
 
     return res;
 }
@@ -2053,7 +2059,7 @@ gchar *get_source_run_time_checkers(Method *method, const gchar *namespace)
         if (parameter && parameter->type && parameter->type[strlen(parameter->type) - 1] == '*') {
             trueType = get_true_type(parameter->type);
             for (i = 0;
-                 trueType[i] && i < namespace_len && namespace[i] == trueType[i];
+                 i < namespace_len && trueType[i] && namespace[i] == trueType[i];
                  i++);
 
             if (i == namespace_len) {
@@ -2156,9 +2162,12 @@ static gint generate_library(const gchar *apis_dir)
     gchar *buffer;
     GList *structures;
     GList *iter_list;
+    GList *filenames = NULL;
+    GList *iter_filenames;
     GDir *dir;
     GError *local_error = NULL;
     gint res = 0;
+    gint len;
 
     g_return_val_if_fail(apis_dir != NULL, 1);
     g_return_val_if_fail(g_file_test(apis_dir, G_FILE_TEST_IS_DIR), 1);
@@ -2186,7 +2195,13 @@ static gint generate_library(const gchar *apis_dir)
 
     /* Parse the all the XML files into the Structure */
     while (filename = g_dir_read_name(dir), filename) {
-        gint len = (gint)strlen(filename);
+        filenames = g_list_prepend(filenames, g_strdup(filename));
+    }
+    filenames = g_list_sort(filenames, (GCompareFunc)g_strcmp0);
+    for (iter_filenames = g_list_first(filenames); iter_filenames != NULL;
+        iter_filenames = g_list_next(iter_filenames)) {
+        filename = iter_filenames->data;
+        len = (gint)strlen(filename);
 
         if (len <= 4 || g_ascii_strncasecmp(filename + len - 4, ".xml", 4) != 0)
             continue;
@@ -2280,6 +2295,7 @@ static gint generate_library(const gchar *apis_dir)
     g_hash_table_destroy(type2structure);
     g_hash_table_destroy(defaultValues);
     g_list_free_full(structures, (GDestroyNotify)structure_free);
+    g_list_free_full(filenames, g_free);
     g_free(buffer);
 
     return res;
