@@ -24,6 +24,7 @@
 #include "icalerror.h"
 #include "icalmemory.h"
 #include "icalparser.h"
+#include "icalproperty_p.h"
 #include "icalrestriction.h"
 #include "icaltimezone.h"
 
@@ -64,7 +65,6 @@ static void icalcomponent_rename_tzids(icalcomponent *comp, icalarray *rename_ta
 static void icalcomponent_rename_tzids_callback(icalparameter *param, void *data);
 static int icalcomponent_compare_vtimezones(icalcomponent *vtimezone1, icalcomponent *vtimezone2);
 static int icalcomponent_compare_timezone_fn(const void *elem1, const void *elem2);
-static struct icaltimetype icalcomponent_get_datetime(icalcomponent *comp, icalproperty *prop);
 
 void icalcomponent_add_children(icalcomponent *impl, va_list args)
 {
@@ -749,7 +749,7 @@ int icalproperty_recurrence_is_excluded(icalcomponent *comp,
     for (exdate = icalcomponent_get_first_property(comp, ICAL_EXDATE_PROPERTY);
          exdate != NULL; exdate = icalcomponent_get_next_property(comp, ICAL_EXDATE_PROPERTY)) {
 
-        struct icaltimetype exdatetime = icalcomponent_get_datetime(comp, exdate);
+        struct icaltimetype exdatetime = icalproperty_get_datetime_with_component(exdate, comp);
 
         if ((icaltime_is_date(exdatetime) &&
              icaltime_compare_date_only(*recurtime, exdatetime) == 0) ||
@@ -910,10 +910,12 @@ void icalcomponent_foreach_recurrence(icalcomponent *comp,
 
     basespan.is_busy = icalcomponent_is_busy(comp);
 
-  /** Calculate the ceiling and floor values.. **/
-    limit_start = icaltime_as_timet_with_zone(start, icaltimezone_get_utc_timezone());
+    /** Calculate the ceiling and floor values.. **/
+    limit_start = icaltime_as_timet_with_zone(start,
+                                              icaltimezone_get_utc_timezone());
     if (!icaltime_is_null_time(end)) {
-        limit_end = icaltime_as_timet_with_zone(end, icaltimezone_get_utc_timezone());
+        limit_end = icaltime_as_timet_with_zone(end,
+                                                icaltimezone_get_utc_timezone());
     } else {
 #if (SIZEOF_TIME_T > 4)
         limit_end = (time_t) LONG_MAX;
@@ -924,10 +926,12 @@ void icalcomponent_foreach_recurrence(icalcomponent *comp,
     limit_span.start = limit_start;
     limit_span.end = limit_end;
 
-    /* Do the callback for the initial DTSTART entry */
-
-    if (!icalproperty_recurrence_is_excluded(comp, &dtstart, &dtstart)) {
-    /** call callback action **/
+    /* Do the callback for the DTSTART entry, ONLY if there is no RRULE.
+       Otherwise, the initial occurrence will be handled by the RRULE. */
+    rrule = icalcomponent_get_first_property(comp, ICAL_RRULE_PROPERTY);
+    if ((rrule == NULL) &&
+        !icalproperty_recurrence_is_excluded(comp, &dtstart, &dtstart)) {
+        /** call callback action **/
         if (icaltime_span_overlaps(&basespan, &limit_span))
             (*callback) (comp, &basespan, callback_data);
     }
@@ -936,25 +940,29 @@ void icalcomponent_foreach_recurrence(icalcomponent *comp,
     dtduration = basespan.end - basespan.start;
 
     /* Now cycle through the rrule entries */
-    for (rrule = icalcomponent_get_first_property(comp, ICAL_RRULE_PROPERTY);
-         rrule != NULL; rrule = icalcomponent_get_next_property(comp, ICAL_RRULE_PROPERTY)) {
+    for (; rrule != NULL;
+         rrule = icalcomponent_get_next_property(comp, ICAL_RRULE_PROPERTY)) {
 
         struct icalrecurrencetype recur = icalproperty_get_rrule(rrule);
         icalrecur_iterator *rrule_itr = icalrecur_iterator_new(recur, dtstart);
         struct icaltimetype rrule_time;
 
-        if (rrule_itr)
-            rrule_time = icalrecur_iterator_next(rrule_itr);
-    /** note that icalrecur_iterator_next always returns dtstart
-        the first time.. **/
+        if (!rrule_itr) continue;
 
-        while (rrule_itr) {
-            rrule_time = icalrecur_iterator_next(rrule_itr);
+        if (recur.count == 0) {
+            icaltimetype mystart = start;
 
-            if (icaltime_is_null_time(rrule_time))
-                break;
+            /* make sure we include any recurrence that ends in timespan */
+            icaltime_adjust(&mystart, 0, 0, 0, -(int)dtduration);
+            icalrecur_iterator_set_start(rrule_itr, mystart);
+        }
 
-            /* if we have iterated past end time, then no need to check any further */
+        for (rrule_time = icalrecur_iterator_next(rrule_itr);
+             !icaltime_is_null_time(rrule_time);
+             rrule_time = icalrecur_iterator_next(rrule_itr)) {
+
+            /* if we have iterated past end time,
+               then no need to check any further */
             if (icaltime_compare(rrule_time, end) > 0)
                 break;
 
@@ -964,45 +972,50 @@ void icalcomponent_foreach_recurrence(icalcomponent *comp,
                                             icaltimezone_get_utc_timezone());
             recurspan.end = recurspan.start + dtduration;
 
-      /** save the iterator ICK! **/
+            /** save the iterator ICK! **/
             property_iterator = comp->property_iterator;
 
-            if (!icalproperty_recurrence_is_excluded(comp, &dtstart, &rrule_time)) {
-        /** call callback action **/
+            if (!icalproperty_recurrence_is_excluded(comp,
+                                                     &dtstart, &rrule_time)) {
+                /** call callback action **/
                 if (icaltime_span_overlaps(&recurspan, &limit_span))
                     (*callback) (comp, &recurspan, callback_data);
             }
             comp->property_iterator = property_iterator;
-        }       /* end of iteration over a specific RRULE */
+        }   /* end of iteration over a specific RRULE */
 
         icalrecur_iterator_free(rrule_itr);
     }   /* end of RRULE loop */
 
-  /** Now process RDATE entries **/
+    /** Now process RDATE entries **/
     for (rdate = icalcomponent_get_first_property(comp, ICAL_RDATE_PROPERTY);
-         rdate != NULL; rdate = icalcomponent_get_next_property(comp, ICAL_RDATE_PROPERTY)) {
+         rdate != NULL;
+         rdate = icalcomponent_get_next_property(comp, ICAL_RDATE_PROPERTY)) {
 
-        struct icaldatetimeperiodtype rdate_period = icalproperty_get_rdate(rdate);
+        struct icaldatetimeperiodtype rdate_period =
+            icalproperty_get_rdate(rdate);
 
-    /** RDATES can specify raw datetimes, periods, or dates.
-        we only support raw datetimes for now..
+        /** RDATES can specify raw datetimes, periods, or dates.
+            we only support raw datetimes for now..
 
-        @todo Add support for other types **/
+            @todo Add support for other types **/
 
         if (icaltime_is_null_time(rdate_period.time))
             continue;
 
         recurspan.start =
             icaltime_as_timet_with_zone(rdate_period.time,
-                                        rdate_period.time.zone ? rdate_period.time.zone :
+                                        rdate_period.time.zone ?
+                                        rdate_period.time.zone :
                                         icaltimezone_get_utc_timezone());
         recurspan.end = recurspan.start + dtduration;
 
-    /** save the iterator ICK! **/
+        /** save the iterator ICK! **/
         property_iterator = comp->property_iterator;
 
-        if (!icalproperty_recurrence_is_excluded(comp, &dtstart, &rdate_period.time)) {
-      /** call callback action **/
+        if (!icalproperty_recurrence_is_excluded(comp,
+                                                 &dtstart, &rdate_period.time)) {
+            /** call callback action **/
             if (icaltime_span_overlaps(&recurspan, &limit_span))
                 (*callback) (comp, &recurspan, callback_data);
         }
@@ -1413,43 +1426,6 @@ void icalcomponent_set_dtstart(icalcomponent *comp, struct icaltimetype v)
     }
 }
 
-/**     @brief Get a DATE or DATE-TIME property as an icaltime
- *
- *      If the property is a DATE-TIME with a timezone parameter and a
- *      corresponding VTIMEZONE is present in the component, the
- *      returned component will already be in the correct timezone;
- *      otherwise the caller is responsible for converting it.
- *
- *      FIXME this is useless until we can flag the failure
- */
-static struct icaltimetype icalcomponent_get_datetime(icalcomponent *comp, icalproperty *prop)
-{
-    icalcomponent *c;
-    icalparameter *param;
-    struct icaltimetype ret;
-
-    ret = icalvalue_get_datetime(icalproperty_get_value(prop));
-
-    if ((param = icalproperty_get_first_parameter(prop, ICAL_TZID_PARAMETER)) != NULL) {
-        const char *tzid = icalparameter_get_tzid(param);
-        icaltimezone *tz = NULL;
-
-        for (c = comp; c != NULL; c = icalcomponent_get_parent(c)) {
-            tz = icalcomponent_get_timezone(c, tzid);
-            if (tz != NULL)
-                break;
-        }
-
-        if (tz == NULL)
-            tz = icaltimezone_get_builtin_timezone_from_tzid(tzid);
-
-        if (tz != NULL)
-            ret = icaltime_set_timezone(&ret, tz);
-    }
-
-    return ret;
-}
-
 /**     @brief Get DTSTART property as an icaltime
  *
  *      If DTSTART is a DATE-TIME with a timezone parameter and a
@@ -1469,7 +1445,7 @@ struct icaltimetype icalcomponent_get_dtstart(icalcomponent *comp)
         return icaltime_null_time();
     }
 
-    return icalcomponent_get_datetime(comp, prop);
+    return icalproperty_get_datetime_with_component(prop, comp);
 }
 
 /**     @brief Get DTEND property as an icaltime
@@ -1492,7 +1468,7 @@ struct icaltimetype icalcomponent_get_dtend(icalcomponent *comp)
     struct icaltimetype ret = icaltime_null_time();
 
     if (end_prop != 0) {
-        ret = icalcomponent_get_datetime(comp, end_prop);
+        ret = icalproperty_get_datetime_with_component(end_prop, comp);
     } else if (dur_prop != 0) {
 
         struct icaltimetype start = icalcomponent_get_dtstart(inner);
@@ -1674,7 +1650,7 @@ void icalcomponent_set_comment(icalcomponent *comp, const char *v)
         icalcomponent_add_property(inner, prop);
     }
 
-    icalproperty_set_summary(prop, v);
+    icalproperty_set_comment(prop, v);
 }
 
 const char *icalcomponent_get_comment(icalcomponent *comp)
@@ -1709,7 +1685,7 @@ void icalcomponent_set_uid(icalcomponent *comp, const char *v)
         icalcomponent_add_property(inner, prop);
     }
 
-    icalproperty_set_summary(prop, v);
+    icalproperty_set_uid(prop, v);
 }
 
 const char *icalcomponent_get_uid(icalcomponent *comp)
@@ -2491,7 +2467,7 @@ struct icaltimetype icalcomponent_get_due(icalcomponent *comp)
     icalproperty *dur_prop = icalcomponent_get_first_property(inner, ICAL_DURATION_PROPERTY);
 
     if (due_prop != 0) {
-        return icalcomponent_get_datetime(comp, due_prop);
+        return icalproperty_get_datetime_with_component(due_prop, comp);
     } else if (dur_prop != 0) {
 
         struct icaltimetype start = icalcomponent_get_dtstart(inner);
