@@ -477,7 +477,7 @@ static char *parser_get_next_parameter(char *line, char **end)
  * final new line, and include any continuation lines
  */
 char *icalparser_get_line(icalparser *parser,
-                          char *(*line_gen_func) (char *s, size_t size, void *d))
+                          icalparser_line_gen_func line_gen_func)
 {
     char *line;
     char *line_p;
@@ -626,7 +626,7 @@ static int line_is_blank(char *line)
 }
 
 icalcomponent *icalparser_parse(icalparser *parser,
-                                char *(*line_gen_func) (char *s, size_t size, void *d))
+                                icalparser_line_gen_func line_gen_func)
 {
     char *line;
     icalcomponent *c = 0;
@@ -1273,6 +1273,13 @@ char *icalparser_string_line_generator(char *out, size_t buf_size, void *d)
 
     if (data->pos == 0) {
         data->pos = data->str;
+
+        /* Skip the UTF-8 marker at the beginning of the string */
+        if (((unsigned char) data->pos[0]) == 0xEF &&
+            ((unsigned char) data->pos[1]) == 0xBB &&
+            ((unsigned char) data->pos[2]) == 0xBF) {
+            data->pos += 3;
+        }
     }
 
     /* If the pointer is at the end of the string, we are done */
