@@ -20,6 +20,7 @@
 #define ICALPROPERTY_P_H
 
 #include "icalproperty.h"
+#include "icalcomponent.h"
 
 /* Check validity and attributes of icalproperty_kind and icalvalue_kind pair */
 LIBICAL_ICAL_NO_EXPORT int icalproperty_value_kind_is_valid(icalproperty_kind pkind,
@@ -28,5 +29,8 @@ LIBICAL_ICAL_NO_EXPORT int icalproperty_value_kind_is_multivalued(icalproperty_k
                                                                   icalvalue_kind *vkind);
 LIBICAL_ICAL_NO_EXPORT int icalproperty_value_kind_is_default(icalproperty_kind pkind,
                                                               icalvalue_kind vkind);
+LIBICAL_ICAL_NO_EXPORT struct icaltimetype icalproperty_get_datetime_with_component(
+                                                                          icalproperty *prop,
+                                                                          icalcomponent *comp);
 
 #endif /* ICALPROPERTY_P_H */
