@@ -384,6 +384,10 @@ static void icalrecur_clause_name_and_value(struct icalrecur_parser *parser,
     *value = idx;
 }
 
+/* returns < 0 if a parsing problem:
+   -2 if an RSCALE rule is encountered yet we don't RSCALE support enabled
+   -1 for all other parsing problems
+*/
 static int icalrecur_add_byrules(struct icalrecur_parser *parser, short *array,
                                  int min, int size, char *vals)
 {
@@ -426,11 +430,14 @@ static int icalrecur_add_byrules(struct icalrecur_parser *parser, short *array,
 
         if (*t) {
             /* Check for leap month suffix (RSCALE only) */
-            if (icalrecurrencetype_rscale_is_supported() &&
-                array == parser->rt.by_month && strcmp(t, "L") == 0) {
-                /* The "L" suffix in a BYMONTH recur-rule-part
-                   is encoded by setting a high-order bit */
-                v |= LEAP_MONTH;
+            if (array == parser->rt.by_month && strcmp(t, "L") == 0) {
+                if (icalrecurrencetype_rscale_is_supported()) {
+                    /* The "L" suffix in a BYMONTH recur-rule-part
+                       is encoded by setting a high-order bit */
+                    v |= LEAP_MONTH;
+                } else {
+                    return -2;
+                }
             } else {
                 return -1;
             }
@@ -582,14 +589,24 @@ struct icalrecurrencetype icalrecurrencetype_from_string(const char *str)
             }
         } else if (strcasecmp(name, "FREQ") == 0) {
             parser.rt.freq = icalrecur_string_to_freq(value);
-            if (parser.rt.freq == ICAL_NO_RECURRENCE) r = -1;
-        } else if (icalrecurrencetype_rscale_is_supported() &&
-                   strcasecmp(name, "RSCALE") == 0) {
-            parser.rt.rscale = icalmemory_strdup(value);
-        } else if (icalrecurrencetype_rscale_is_supported() &&
-                   strcasecmp(name, "SKIP") == 0) {
-            parser.rt.skip = icalrecur_string_to_skip(value);
-            if (parser.rt.skip == ICAL_SKIP_UNDEFINED) r = -1;
+            if (parser.rt.freq == ICAL_NO_RECURRENCE) {
+                r = -1;
+            }
+        } else if (strcasecmp(name, "RSCALE") == 0) {
+            if (icalrecurrencetype_rscale_is_supported()) {
+                parser.rt.rscale = icalmemory_strdup(value);
+            } else {
+                r = -2; // RSCALE clause name without RSCALE support
+            }
+        } else if (strcasecmp(name, "SKIP") == 0) {
+            if (icalrecurrencetype_rscale_is_supported()) {
+                parser.rt.skip = icalrecur_string_to_skip(value);
+                if (parser.rt.skip == ICAL_SKIP_UNDEFINED) {
+                    r = -1;
+                }
+            } else {
+                r = -2; // RSCALE clause name without RSCALE support
+            }
         } else if (strcasecmp(name, "COUNT") == 0) {
             parser.rt.count = atoi(value);
             /* don't allow count to be less than 1 */
@@ -640,8 +657,15 @@ struct icalrecurrencetype icalrecurrencetype_from_string(const char *str)
         }
 
         if (r) {
-            icalerror_set_errno(ICAL_MALFORMEDDATA_ERROR);
-            free(parser.rt.rscale);
+            /* Note: silently ignore when we have an RSCALE rule, yet don't have RSCALE support.
+               The magic value "-2" indicates when that happens.
+            */
+            if (r != -2) {
+                icalerror_set_errno(ICAL_MALFORMEDDATA_ERROR);
+            }
+            if (parser.rt.rscale) {
+                free(parser.rt.rscale);
+            }
             icalrecurrencetype_clear(&parser.rt);
             break;
         }
@@ -1322,7 +1346,7 @@ static short decode_day(short *day, unsigned int flags)
     return icalrecurrencetype_day_position(*day);
 }
 
-static int initialize_iterator(icalrecur_iterator *impl)
+static int initialize_rscale(icalrecur_iterator *impl)
 {
     struct icalrecurrencetype rule = impl->rule;
     struct icaltimetype dtstart = impl->dtstart;
@@ -1428,17 +1452,6 @@ static int initialize_iterator(icalrecur_iterator *impl)
     /* Get rstart (DTSTART in RSCALE) */
     impl->rstart = occurrence_as_icaltime(impl, 0);
 
-    /* Set up defaults for BY_* arrays */
-    setup_defaults(impl, BY_SECOND, impl->rstart.second);
-
-    setup_defaults(impl, BY_MINUTE, impl->rstart.minute);
-
-    setup_defaults(impl, BY_HOUR, impl->rstart.hour);
-
-    setup_defaults(impl, BY_MONTH_DAY, impl->rstart.day);
-
-    setup_defaults(impl, BY_MONTH, impl->rstart.month);
-
     return 1;
 }
 
@@ -1447,6 +1460,9 @@ static void set_datetime(icalrecur_iterator *impl, icaltimetype date)
 {
     UErrorCode status = U_ZERO_ERROR;
 
+    impl->last.is_date = impl->rstart.is_date;
+    impl->last.zone = impl->rstart.zone;
+
     if (impl->rstart.is_date) {
         ucal_setDate(impl->greg,
                      (int32_t) date.year,
@@ -1727,18 +1743,9 @@ static void increment_second(icalrecur_iterator *impl, int inc)
     icaltime_adjust(&impl->last, 0, 0, 0, inc);
 }
 
-static int initialize_iterator(icalrecur_iterator *impl)
+static int initialize_rscale(icalrecur_iterator *impl)
 {
-    /* Set up defaults for BY_* arrays */
-    setup_defaults(impl, BY_SECOND, impl->dtstart.second);
-
-    setup_defaults(impl, BY_MINUTE, impl->dtstart.minute);
-
-    setup_defaults(impl, BY_HOUR, impl->dtstart.hour);
-
-    setup_defaults(impl, BY_MONTH_DAY, impl->dtstart.day);
-
-    setup_defaults(impl, BY_MONTH, impl->dtstart.month);
+    impl->rstart = impl->dtstart;
 
     return 1;
 }
@@ -1749,6 +1756,8 @@ static void set_datetime(icalrecur_iterator *impl, icaltimetype date)
     impl->last.year = date.year;
     impl->last.month = date.month;
     impl->last.day = date.day;
+    impl->last.is_date = impl->dtstart.is_date;
+    impl->last.zone = impl->dtstart.zone;
 
     if (!impl->dtstart.is_date) {
         impl->last.hour = has_by_data(impl, BY_HOUR) ?
@@ -1776,6 +1785,7 @@ static int day_diff(icalrecur_iterator *impl, icaltimetype a, icaltimetype b)
 
 #endif /* HAVE_LIBICU */
 
+static int __iterator_set_start(icalrecur_iterator *impl, icaltimetype start);
 static void increment_month(icalrecur_iterator *impl);
 static int expand_month_days(icalrecur_iterator *impl, int year, int month);
 static int expand_year_days(icalrecur_iterator *impl, int year);
@@ -1813,7 +1823,6 @@ icalrecur_iterator *icalrecur_iterator_new(struct icalrecurrencetype rule,
 {
     icalrecur_iterator *impl;
     icalrecurrencetype_frequency freq = rule.freq;
-    struct icaltimetype last;
     enum byrule byrule;
 
     icalerror_clear_errno();
@@ -1847,11 +1856,6 @@ icalrecur_iterator *icalrecur_iterator_new(struct icalrecurrencetype rule,
 
     impl->dtstart = dtstart;
     impl->rule = rule;
-    impl->rstart = dtstart;
-    impl->istart = dtstart;
-    impl->last = dtstart;
-    impl->occurrence_no = 0;
-    impl->days_index = ICAL_YEARDAYS_MASK_SIZE;
 
     /* Set up convenience pointers to make the code simpler. Allows
        us to iterate through all of the BY* arrays in the rule. */
@@ -1903,85 +1907,24 @@ icalrecur_iterator *icalrecur_iterator_new(struct icalrecurrencetype rule,
         }
     }
 
-    /* Rewrite some of the rules and set up defaults to make later
-       processing easier. Primarily, it involves copying an element
-       from the start time into the corresponding BY_* array when the
-       BY_* array is empty */
-
-    if (initialize_iterator(impl) == 0) {
+    if (initialize_rscale(impl) == 0) {
         icalrecur_iterator_free(impl);
         return 0;
     }
 
-    last = occurrence_as_icaltime(impl, 0);
+    /* Set up defaults for BY_* arrays */
+    setup_defaults(impl, BY_SECOND, impl->rstart.second);
 
-    switch (impl->rule.freq) {
-    case ICAL_WEEKLY_RECURRENCE:
+    setup_defaults(impl, BY_MINUTE, impl->rstart.minute);
 
-        if (impl->by_ptrs[BY_DAY][0] == ICAL_RECURRENCE_ARRAY_MAX) {
+    setup_defaults(impl, BY_HOUR, impl->rstart.hour);
 
-            /* Weekly recurrences with no BY_DAY data should occur on the
-               same day of the week as the start time . */
-            impl->by_ptrs[BY_DAY][0] = (short)get_day_of_week(impl);
+    setup_defaults(impl, BY_MONTH_DAY, impl->rstart.day);
 
-        } else {
-            adjust_to_byday(impl);
-        }
-        break;
+    setup_defaults(impl, BY_MONTH, impl->rstart.month);
 
-    case ICAL_YEARLY_RECURRENCE:
-        /* For YEARLY rule, begin by setting up the year days array.
-           The YEARLY rules work by expanding one year at a time. */
-
-        /* Fail after hitting the year 20000 if no expanded days match */
-        while (last.year < 20000) {
-            expand_year_days(impl, last.year);
-            if (icalerrno != ICAL_NO_ERROR) {
-                icalerror_set_errno(ICAL_MALFORMEDDATA_ERROR);
-                free(impl);
-                return 0;
-            }
-            if (impl->days_index < ICAL_YEARDAYS_MASK_SIZE) {
-                break;  /* break when a matching day is found */
-            }
-            increment_year(impl, impl->rule.interval);
-            last = occurrence_as_icaltime(impl, 0);
-        }
-
-        /* Copy the first day into last. */
-        set_day_of_year(impl, impl->days_index);
-
-        break;
-
-    case ICAL_MONTHLY_RECURRENCE:
-        /* For MONTHLY rule, begin by setting up the year days array.
-           The MONTHLY rules work by expanding one month at a time. */
-
-        /* Fail after hitting the year 20000 if no expanded days match */
-        while (last.year < 20000) {
-            expand_month_days(impl, last.year, last.month);
-            if (impl->days_index < ICAL_YEARDAYS_MASK_SIZE) {
-                break;  /* break when a matching day is found */
-            }
-            increment_month(impl);
-            last = occurrence_as_icaltime(impl, 0);
-        }
-
-        /* Copy the first day into last. */
-        set_day_of_year(impl, impl->days_index);
-
-        break;
-
-    default:
-        break;
-    }
-
-    impl->last = occurrence_as_icaltime(impl, 1);
-
-    /* Fail if first instance exceeds MAX_TIME_T_YEAR */
-    if (impl->last.year > MAX_TIME_T_YEAR) {
-        icalerror_set_errno(ICAL_MALFORMEDDATA_ERROR);
-        free(impl);
+    if (!__iterator_set_start(impl, dtstart)) {
+        icalrecur_iterator_free(impl);
         return 0;
     }
 
@@ -2031,31 +1974,23 @@ static int __day_diff(icalrecur_iterator *impl, icaltimetype a, icaltimetype b)
    available. */
 static void increment_month(icalrecur_iterator *impl)
 {
+    int inc = impl->rule.interval;
+
+    __increment_month(impl, inc);
+
     if (has_by_data(impl, BY_MONTH)) {
-        /* Ignore the frequency and use the byrule data */
+        struct icaltimetype this = occurrence_as_icaltime(impl, 0);
 
-        do {
-            BYMONIDX++;
+        while (this.year < 20000) {
+            for (BYMONIDX = 0;
+                 BYMONPTR[BYMONIDX] != ICAL_RECURRENCE_ARRAY_MAX; BYMONIDX++) {
 
-            if (BYMONPTR[BYMONIDX] == ICAL_RECURRENCE_ARRAY_MAX) {
-                BYMONIDX = 0;
-
-                increment_year(impl, 1);
+                if (this.month == BYMONPTR[BYMONIDX]) return;
             }
 
-        } while (!set_month(impl, BYMONPTR[BYMONIDX]));
-
-    } else {
-
-        int inc;
-
-        if (impl->rule.freq == ICAL_MONTHLY_RECURRENCE) {
-            inc = impl->rule.interval;
-        } else {
-            inc = 1;
+            __increment_month(impl, inc);
+            this = occurrence_as_icaltime(impl, 0);
         }
-
-        __increment_month(impl, inc);
     }
 }
 
@@ -2908,43 +2843,26 @@ struct icaltimetype icalrecur_iterator_next(icalrecur_iterator *impl)
     return impl->last;
 }
 
-int icalrecur_iterator_set_start(icalrecur_iterator *impl,
-                                 struct icaltimetype start)
+static int __iterator_set_start(icalrecur_iterator *impl, icaltimetype start)
 {
+    icalrecurrencetype_frequency freq = impl->rule.freq;
     short interval = impl->rule.interval;
     int diff;
 
-    /* We can't adjust start date if we need to count occurrences */
-    if (impl->rule.count > 0) {
-        icalerror_set_errno(ICAL_MALFORMEDDATA_ERROR);
-        return 0;
-    }
-
-    /* Convert start to same time zone as DTSTART */
-    impl->istart =
-        icaltime_convert_to_zone(start, (icaltimezone *) impl->dtstart.zone);
-
-    if (icaltime_compare(impl->istart, impl->dtstart) < 0) {
-        /* If start is before DTSTART, use DTSTART */
-        impl->istart = impl->dtstart;
-    }
-    else if (!icaltime_is_null_time(impl->rule.until) &&
-        icaltime_compare(impl->istart, impl->rule.until) > 0) {
-        /* If start is after UNTIL, we're done */
-        impl->last = impl->istart;
-        return 1;
-    }
+    impl->istart = start;
+    impl->occurrence_no = 0;
+    impl->days_index = ICAL_YEARDAYS_MASK_SIZE;
 
     /* Set Gregorian start date */
-    set_datetime(impl, impl->istart);
+    set_datetime(impl, start);
 
-    /* Get start date as RSCALE date */
-    start = occurrence_as_icaltime(impl, 0);
-
-    switch (impl->rule.freq) {
+    switch (freq) {
     case ICAL_YEARLY_RECURRENCE:
+        /* For YEARLY rule, begin by setting up the year days array.
+           The YEARLY rules work by expanding one year at a time. */
+
         if ((interval > 1) &&
-            (diff = (start.year - impl->rstart.year) % interval)) {
+            (diff = (impl->istart.year - impl->rstart.year) % interval)) {
             /* Specified start year doesn't match interval -
                bump start to first day of next year that matches interval */
             set_day_of_year(impl, 1);
@@ -2954,8 +2872,20 @@ int icalrecur_iterator_set_start(icalrecur_iterator *impl,
         /* Get (adjusted) start date as RSCALE date */
         start = occurrence_as_icaltime(impl, 0);
 
-        /* Expand days array for (adjusted) start year */
-        expand_year_days(impl, start.year);
+        /* Expand days array for (adjusted) start year -
+           fail after hitting the year 20000 if no expanded days match */
+        while (start.year < 20000) {
+            expand_year_days(impl, start.year);
+            if (icalerrno != ICAL_NO_ERROR) {
+                icalerror_set_errno(ICAL_MALFORMEDDATA_ERROR);
+                return 0;
+            }
+            if (impl->days_index < ICAL_YEARDAYS_MASK_SIZE) {
+                break;  /* break when a matching day is found */
+            }
+            increment_year(impl, interval);
+            start = occurrence_as_icaltime(impl, 0);
+        }
 
         /* Copy the first day into last */
         set_day_of_year(impl, impl->days_index);
@@ -2963,19 +2893,30 @@ int icalrecur_iterator_set_start(icalrecur_iterator *impl,
         break;
 
     case ICAL_MONTHLY_RECURRENCE:
+        /* For MONTHLY rule, begin by setting up the year days array.
+           The MONTHLY rules work by expanding one month at a time. */
+
         if ((interval > 1) &&
-            (diff = month_diff(impl, impl->rstart, start) % interval)) {
+            (diff = month_diff(impl, impl->rstart, impl->istart) % interval)) {
             /* Specified month doesn't match interval -
                bump start to first day of next month that matches interval */
-            increment_monthday(impl, -start.day);
+            increment_monthday(impl, -impl->istart.day + 1);
             __increment_month(impl, interval - diff);
         }
 
         /* Get (adjusted) start date as RSCALE date */
         start = occurrence_as_icaltime(impl, 0);
 
-        /* Expand days array for (adjusted) start month */
-        expand_month_days(impl, start.year, start.month);
+        /* Expand days array for (adjusted) start month -
+           fail after hitting the year 20000 if no expanded days match */
+        while (start.year < 20000) {
+            expand_month_days(impl, start.year, start.month);
+            if (impl->days_index < ICAL_YEARDAYS_MASK_SIZE) {
+                break;  /* break when a matching day is found */
+            }
+            increment_month(impl);
+            start = occurrence_as_icaltime(impl, 0);
+        }
 
         /* Copy the first day into last */
         set_day_of_year(impl, impl->days_index);
@@ -2983,23 +2924,29 @@ int icalrecur_iterator_set_start(icalrecur_iterator *impl,
         break;
 
     case ICAL_WEEKLY_RECURRENCE:
+        if (impl->by_ptrs[BY_DAY][0] == ICAL_RECURRENCE_ARRAY_MAX) {
+            /* Weekly recurrences with no BY_DAY data should occur on the
+               same day of the week as the start time . */
+            impl->by_ptrs[BY_DAY][0] = (short)get_day_of_week(impl);
 
-        adjust_to_byday(impl);
+        } else {
+            adjust_to_byday(impl);
 
-        /* Get adjusted start date as RSCALE date */
-        start = occurrence_as_icaltime(impl, 0);
+            /* Get (adjusted) start date as RSCALE date */
+            start = occurrence_as_icaltime(impl, 0);
 
-        if ((interval > 1) &&
-            (diff = (day_diff(impl, impl->rstart, start) + 6) / 7) % interval) {
-            /* Specified day doesn't match interval -
-               bump start to next week that matches interval */
-            increment_monthday(impl, 7 * (interval - diff));
+            if ((interval > 1) &&
+                (diff = (day_diff(impl, impl->rstart, start) + 6) / 7) % interval) {
+                /* Specified week doesn't match interval -
+                   bump start to next week that matches interval */
+                increment_monthday(impl, 7 * (interval - diff));
+            }
         }
         break;
 
     case ICAL_DAILY_RECURRENCE:
         if ((interval > 1) &&
-            (diff = day_diff(impl, impl->rstart, start) % interval)) {
+            (diff = day_diff(impl, impl->rstart, impl->istart) % interval)) {
             /* Specified day doesn't match interval -
                bump start to next day that matches interval */
             increment_monthday(impl, interval - diff);
@@ -3010,14 +2957,44 @@ int icalrecur_iterator_set_start(icalrecur_iterator *impl,
         break;
     }
 
-    /* Re-initialize iterator */
-    impl->occurrence_no = 0;
-    memset(impl->by_indices, 0, sizeof(impl->by_indices));
+    /* Get start date as Gregorian date */
     impl->last = occurrence_as_icaltime(impl, 1);
 
+    /* Fail if first instance exceeds MAX_TIME_T_YEAR */
+    if (impl->last.year > MAX_TIME_T_YEAR) {
+        icalerror_set_errno(ICAL_MALFORMEDDATA_ERROR);
+        return 0;
+    }
+
     return 1;
 }
 
+int icalrecur_iterator_set_start(icalrecur_iterator *impl,
+                                 struct icaltimetype start)
+{
+    /* We can't adjust start date if we need to count occurrences */
+    if (impl->rule.count > 0) {
+        icalerror_set_errno(ICAL_MALFORMEDDATA_ERROR);
+        return 0;
+    }
+
+    /* Convert start to same time zone as DTSTART */
+    start = icaltime_convert_to_zone(start, (icaltimezone *) impl->dtstart.zone);
+
+    if (icaltime_compare(start, impl->dtstart) < 0) {
+        /* If start is before DTSTART, use DTSTART */
+        start = impl->dtstart;
+    }
+    else if (!icaltime_is_null_time(impl->rule.until) &&
+        icaltime_compare(start, impl->rule.until) > 0) {
+        /* If start is after UNTIL, we're done */
+        impl->last = start;
+        return 1;
+    }
+
+    return __iterator_set_start(impl, start);
+}
+
 /************************** Type Routines **********************/
 
 void icalrecurrencetype_clear(struct icalrecurrencetype *recur)
@@ -3113,7 +3090,8 @@ int icalrecur_expand_recurrence(const char *rule,
         }
         icalrecur_iterator_free(ritr);
     }
-    free(recur.rscale);
+    if(recur.rscale)
+        free(recur.rscale);
 
     return 1;
 }
