@@ -4,7 +4,7 @@
 
  (C) COPYRIGHT 2000, Eric Busboom <eric@softwarestudio.org>
 
- This program is free software; you can redistribute it and/or modify
+ This library is free software; you can redistribute it and/or modify
  it under the terms of either:
 
     The LGPL as published by the Free Software Foundation, version
@@ -12,13 +12,13 @@
 
  Or:
 
-    The Mozilla Public License Version 1.0. You may obtain a copy of
+    The Mozilla Public License Version 2.0. You may obtain a copy of
     the License at http://www.mozilla.org/MPL/
 
  The Original Code is eric. The Initial Developer of the Original
  Code is Eric Busboom
 ======================================================================*/
-
+//krazy:excludeall=cpp
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -38,13 +38,13 @@
 /** Default options used when NULL is passed to icalset_new() **/
 icalfileset_options icalfileset_options_default = { O_RDWR | O_CREAT, 0644, 0, NULL };
 
+static int _compare_ids(const char *compid, const char *matchid);
+
 static int icalfileset_lock(icalfileset *set);
 static int icalfileset_unlock(icalfileset *set);
 static icalerrorenum icalfileset_read_file(icalfileset *set, int mode);
 static long icalfileset_filesize(icalfileset *set);
 
-icalerrorenum icalfileset_create_cluster(const char *path);
-
 icalset *icalfileset_new(const char *path)
 {
     return icalset_new(ICAL_FILE_SET, path, &icalfileset_options_default);
@@ -600,7 +600,7 @@ static struct icalfileset_id icalfileset_get_id(icalcomponent *comp)
     p = icalcomponent_get_first_property(inner, ICAL_RECURRENCEID_PROPERTY);
 
     if (p == 0) {
-        id.recurrence_id = 0;
+        id.recurrence_id = NULL;
     } else {
         icalvalue *v;
 
@@ -616,6 +616,22 @@ static struct icalfileset_id icalfileset_get_id(icalcomponent *comp)
 /* Find the component that is related to the given
    component. Currently, it just matches based on UID and
    RECURRENCE-ID */
+
+static int _compare_ids(const char *compid, const char *matchid)
+{
+    if (compid != NULL && matchid != NULL) {
+        if (strcmp(compid, matchid) == 0) {
+            return 1;
+        }
+    }
+
+    if (compid == NULL && matchid == NULL) {
+        return 1;
+    }
+
+    return 0;
+}
+
 icalcomponent *icalfileset_fetch_match(icalset *set, icalcomponent *comp)
 {
     icalfileset *fset = (icalfileset *) set;
@@ -632,9 +648,8 @@ icalcomponent *icalfileset_fetch_match(icalset *set, icalcomponent *comp)
 
         match_id = icalfileset_get_id(match);
 
-        if (strcmp(comp_id.uid, match_id.uid) == 0 &&
-            (comp_id.recurrence_id == 0 ||
-             strcmp(comp_id.recurrence_id, match_id.recurrence_id) == 0)) {
+        if (_compare_ids(comp_id.uid, match_id.uid) &&
+            _compare_ids(comp_id.recurrence_id, match_id.recurrence_id)) {
 
             /* HACK. What to do with SEQUENCE? */
 
@@ -759,7 +774,7 @@ icalsetiter icalfileset_begin_component(icalset *set, icalcomponent_kind kind, i
 
     icalerror_check_arg_re((set != 0), "set", icalsetiter_null);
 
-    start = icaltime_from_timet(time(0), 0);
+    start = icaltime_from_timet_with_zone(time(0), 0, NULL);
     itr.gauge = gauge;
 
     fset = (icalfileset *) set;
@@ -840,7 +855,7 @@ icalcomponent *icalfileset_form_a_matched_recurrence_component(icalsetiter *itr)
     icalproperty *dtstart, *rrule, *prop, *due;
     struct icalrecurrencetype recur;
 
-    start = icaltime_from_timet(time(0), 0);
+    start = icaltime_from_timet_with_zone(time(0), 0, NULL);
     comp = itr->last_component;
 
     if (comp == NULL || itr->gauge == NULL) {
@@ -906,8 +921,8 @@ icalcomponent *icalfilesetiter_to_next(icalset *set, icalsetiter *i)
 
     _unused(set);
 
-    start = icaltime_from_timet(time(0), 0);
-    next = icaltime_from_timet(time(0), 0);
+    start = icaltime_from_timet_with_zone(time(0), 0, NULL);
+    next = icaltime_from_timet_with_zone(time(0), 0, NULL);
 
     do {
         c = icalcompiter_next(&(i->iter));
