@@ -2,7 +2,7 @@
  FILE: icalset.c
  CREATOR: eric 17 Jul 2000
 
- (C) COPYRIGHT 2000, Eric Busboom <eric@civicknowledge.com>
+ (C) COPYRIGHT 2000, Eric Busboom <eric@softwarestudio.org>
 
  Icalset is the "base class" for representations of a collection of
  iCal components. Derived classes (actually delegates) include:
@@ -16,12 +16,12 @@
  it under the terms of either:
 
     The LGPL as published by the Free Software Foundation, version
-    2.1, available at: https://www.gnu.org/licenses/lgpl-2.1.html
+    2.1, available at: http://www.gnu.org/licenses/lgpl-2.1.html
 
  Or:
 
     The Mozilla Public License Version 2.0. You may obtain a copy of
-    the License at https://www.mozilla.org/MPL/
+    the License at http://www.mozilla.org/MPL/
 
  The Original Code is eric. The Initial Developer of the Original
  Code is Eric Busboom
@@ -145,7 +145,6 @@ static int load(const char *file)
 {
     void *modh;
     fptr inith;
-    char *dlerr;
     icalset *icalset_init_ptr;
 
     if ((modh = dlopen(file, RTLD_NOW)) == 0) {
@@ -153,12 +152,8 @@ static int load(const char *file)
         return 0;
     }
 
-    (void)dlerror(); /* clear */
-    inith = (fptr)dlsym(modh, "InitModule");
-    dlerr = dlerror();
-    if (dlerr != NULL) {
-        fprintf(stderr, "dlsym error: %s\n", dlerr);
-        dlclose(modh);
+    if ((inith = (fptr)dlsym(modh, "InitModule")) == 0) {
+        perror("dlsym");
         return 0;
     }
 
@@ -166,8 +161,6 @@ static int load(const char *file)
         pvl_push(icalset_kinds, &icalset_init_ptr);
     }
 
-    (void)dlerror(); /* clear */
-    dlclose(modh);
     return 1;
 }
 
@@ -194,6 +187,7 @@ int icalset_loaddir(const char *path)
         return 0;
     }
 
+    /* cppcheck-suppress readdirCalled since readdir is recommended */
     while ((dp = readdir(d)) != 0) {
         if (strncmp(dp->d_name, "mod_", 4)) {
             continue;
@@ -220,6 +214,8 @@ static void icalset_init(void)
     pvl_push(icalset_kinds, &icalset_dirset_init);
 #if defined(HAVE_BDB)
     pvl_push(icalset_kinds, &icalset_bdb4set_init);
+#else
+#error 3
 #endif
 
     icalset_init_done++;
