@@ -125,18 +125,19 @@
 /*  FILE: icalssyacc.y                                                     */
 /*  CREATOR: eric 08 Aug 2000                                              */
 /*                                                                         */
-/*  (C) COPYRIGHT 2000, Eric Busboom <eric@civicknowledge.com>             */
+/*  (C) COPYRIGHT 2000, Eric Busboom <eric@softwarestudio.org>             */
+/*      http://www.softwarestudio.org                                      */
 /*                                                                         */
 /* This program is free software; you can redistribute it and/or modify    */
 /* it under the terms of either:                                           */
 /*                                                                         */
 /*    The LGPL as published by the Free Software Foundation, version       */
-/*    2.1, available at: https://www.gnu.org/licenses/lgpl-2.1.html         */
+/*    2.1, available at: http://www.gnu.org/licenses/lgpl-2.1.html         */
 /*                                                                         */
 /*  Or:                                                                    */
 /*                                                                         */
 /*    The Mozilla Public License Version 2.0. You may obtain a copy of     */
-/*    the License at https://www.mozilla.org/MPL/                           */
+/*    the License at http://www.mozilla.org/MPL/                           */
 /*                                                                         */
 /* The Original Code is eric. The Initial Developer of the Original        */
 /* Code is Eric Busboom                                                    */
@@ -152,8 +153,8 @@
 
 extern struct icalgauge_impl *icalss_yy_gauge;
 
-//#define YYPARSE_PARAM yy_globals
-//#define YYLEX_PARAM yy_globals
+#define YYPARSE_PARAM yy_globals
+#define YYLEX_PARAM yy_globals
 #define YY_EXTRA_TYPE  icalgauge_impl*
 
 
@@ -340,7 +341,7 @@ YYID (i)
 #  ifndef YYSTACK_ALLOC_MAXIMUM
 #   define YYSTACK_ALLOC_MAXIMUM YYSIZE_MAXIMUM
 #  endif
-#  if (defined __cplusplus || defined __CYGWIN__ && ! defined _STDLIB_H \
+#  if (defined __cplusplus && ! defined _STDLIB_H \
        && ! ((defined YYMALLOC || defined malloc) \
              && (defined YYFREE || defined free)))
 #   include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
@@ -880,7 +881,7 @@ int yydebug;
 # define YYMAXDEPTH 10000
 #endif
 
-
+
 
 #if YYERROR_VERBOSE
 
@@ -1091,7 +1092,7 @@ yysyntax_error (char *yyresult, int yystate, int yychar)
     }
 }
 #endif /* YYERROR_VERBOSE */
-
+
 
 /*-----------------------------------------------.
 | Release the memory associated to this symbol.  |
@@ -1123,7 +1124,7 @@ yydestruct (yymsg, yytype, yyvaluep)
         break;
     }
 }
-
+
 
 /* Prevent warnings from -Wmissing-prototypes.  */
 
@@ -1317,7 +1318,6 @@ yyparse ()
       YYDPRINTF ((stderr, "Stack size increased to %lu\n",
                   (unsigned long int) yystacksize));
 
-      /* coverity[OVERRUN] */
       if (yyss + yystacksize - 1 <= yyssp)
         YYABORT;
     }
@@ -1419,9 +1419,9 @@ yyreduce:
      users should not rely upon it.  Assigning to YYVAL
      unconditionally makes the parser a bit smaller, and it avoids a
      GCC warning that YYVAL may be used uninitialized.  */
-  /* coverity[uninit_use] */
   yyval = yyvsp[1-yylen];
 
+
   YY_REDUCE_PRINT (yyn);
   switch (yyn)
     {
@@ -1599,11 +1599,9 @@ yyerrorlab:
   /* Pacify compilers like GCC when the user code never invokes
      YYERROR and the label yyerrorlab therefore never appears in user
      code.  */
-#pragma clang diagnostic push
-#pragma clang diagnostic ignored "-Wunreachable-code"
-    if (/*CONSTCOND*/ 0)
+  if (/*CONSTCOND*/ 0)
      goto yyerrorlab;
-#pragma clang diagnostic pop
+
   /* Do not reclaim the symbols of the rule which action triggered
      this YYERROR.  */
   YYPOPSTACK (yylen);
@@ -1853,7 +1851,7 @@ static void ssyacc_add_from(struct icalgauge_impl* impl, char* str1)
         assert(0);
     }
 
-    pvl_push(impl->from,(void *)ckind);
+    pvl_push(impl->from,(void*)ckind);
 
 }
 
