@@ -8,79 +8,23 @@
  it under the terms of either:
 
     The LGPL as published by the Free Software Foundation, version
-    2.1, available at: https://www.gnu.org/licenses/lgpl-2.1.html
+    2.1, available at: http://www.gnu.org/licenses/lgpl-2.1.html
 
  Or:
 
     The Mozilla Public License Version 2.0. You may obtain a copy of
-    the License at https://www.mozilla.org/MPL/
+    the License at http://www.mozilla.org/MPL/
 ======================================================================*/
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
 
-#ifdef HAVE_PTHREAD_H
-#include <pthread.h>
-#include <assert.h>
-#endif
-
 #include "libical/ical.h"
 
 #include <stdio.h>
 
-#if defined(HAVE_PTHREAD_H) && defined(HAVE_PTHREAD) && defined(HAVE_PTHREAD_CREATE)
-
-#define N_THREADS 20
-
-static pthread_mutex_t thread_comp_mutex = PTHREAD_MUTEX_INITIALIZER;
-static const void *thread_comp = NULL;
-
-static void *thread_func(void *user_data)
-{
-    icaltimezone *zone = user_data;
-    icalcomponent *icalcomp;
-
-    if (!zone) {
-        return NULL;
-    }
-
-    icalcomp = icaltimezone_get_component(zone);
-    pthread_mutex_lock(&thread_comp_mutex);
-    if (!thread_comp) {
-        thread_comp = icalcomp;
-    } else {
-        assert(thread_comp == icalcomp);
-    }
-    pthread_mutex_unlock(&thread_comp_mutex);
-    /* Do not call the clone, it confuses the Thread Sanitizer, which
-       claims data race on the internal members of the icalcomp. */
-    /* icalcomp = icalcomponent_new_clone(icalcomp);
-       icalcomponent_free(icalcomp);
-    */
-
-    return NULL;
-}
-
-static void test_get_component_threadsafety(void)
-{
-    pthread_t thread[N_THREADS];
-    icaltimezone *zone;
-    int ii;
-
-    zone = icaltimezone_get_builtin_timezone("Europe/London");
-
-    for (ii = 0; ii < N_THREADS; ii++) {
-        pthread_create(&thread[ii], NULL, thread_func, zone);
-    }
-
-    for (ii = 0; ii < N_THREADS; ii++) {
-        pthread_join(thread[ii], NULL);
-    }
-}
-#endif
-
-int main(void)
+int main()
 {
     icalarray *builtin_timezones;
     icaltimetype tt;
@@ -90,10 +34,6 @@ int main(void)
     set_zone_directory("../../zoneinfo");
     icaltimezone_set_tzid_prefix("/softwarestudio.org/");
 
-#if defined(HAVE_PTHREAD_H) && defined(HAVE_PTHREAD) && defined(HAVE_PTHREAD_CREATE)
-    test_get_component_threadsafety();
-#endif
-
     tt = icaltime_current_time_with_zone(icaltimezone_get_builtin_timezone("America/New_York"));
 
     tt.year = 2038;
