@@ -9,19 +9,15 @@
 # it under the terms of either:
 #
 #   The LGPL as published by the Free Software Foundation, version
-#   2.1, available at: https://www.gnu.org/licenses/lgpl-2.1.txt
+#   2.1, available at: http://www.gnu.org/licenses/lgpl-2.1.txt
 #
 # Or:
 #
 #   The Mozilla Public License Version 2.0. You may obtain a copy of
-#   the License at https://www.mozilla.org/MPL/
+#   the License at http://www.mozilla.org/MPL/
 #
 ###############################################################################
 
-import gi
-
-gi.require_version('ICalGLib', '3.0')
-
 from gi.repository import ICalGLib
 
 message = "This is a stinky error!";
