@@ -11,15 +11,16 @@
 
      ./recur ../../test-data/recur.txt
 
- The contents of this file are subject to the Mozilla Public License
- Version 1.0 (the "License"); you may not use this file except in
- compliance with the License. You may obtain a copy of the License at
- http://www.mozilla.org/MPL/
+ This library is free software; you can redistribute it and/or modify
+ it under the terms of either:
 
- Software distributed under the License is distributed on an "AS IS"
- basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See
- the License for the specific language governing rights and
- limitations under the License.
+    The LGPL as published by the Free Software Foundation, version
+    2.1, available at: http://www.gnu.org/licenses/lgpl-2.1.html
+
+ Or:
+
+    The Mozilla Public License Version 2.0. You may obtain a copy of
+    the License at http://www.mozilla.org/MPL/
  ======================================================================*/
 
 #ifdef HAVE_CONFIG_H
@@ -58,7 +59,7 @@ int main(int argc, char *argv[])
     struct icalrecurrencetype recur;
     icalrecur_iterator *ritr;
     time_t tt;
-    char *file;
+    const char *file;
 
     icalerror_set_error_state(ICAL_PARSE_ERROR, ICAL_ERROR_NONFATAL);
 
@@ -67,7 +68,7 @@ int main(int argc, char *argv[])
 #endif
 
     if (argc <= 1) {
-        file = "../../test-data/recur.txt";
+        file = TEST_DATADIR "/recur.txt";
     } else if (argc == 2) {
         file = argv[1];
     } else {
